@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import json
 import os
+import re
 from distutils.version import LooseVersion
 
 import pip
@@ -17,9 +18,9 @@ try:
     from xmlrpc.client import ServerProxy
 except ImportError:
     # Python 2
-    from urlparse import urlparse
-    from urllib2 import HTTPError, Request, urlopen
-    from xmlrpclib import ServerProxy
+    from urlparse import urlparse  # type: ignore
+    from urllib2 import HTTPError, Request, urlopen  # type: ignore
+    from xmlrpclib import ServerProxy  # type: ignore
 
 try:
     import requests
@@ -108,6 +109,9 @@ class Command(BaseCommand):
         req = Request(url, headers=headers)
         return json.loads(urlopen(req).read())
 
+    def _is_stable(self, version):
+        return not re.search(r'([ab]|rc)\d+$', str(version))
+
     def _available_version(self, dist_version, available):
         if self._is_stable(dist_version):
             stable = [v for v in available if self._is_stable(LooseVersion(v))]
@@ -132,7 +136,7 @@ class Command(BaseCommand):
             elif "dist" in req:
                 dist = req["dist"]
                 dist_version = LooseVersion(dist.version)
-                available = pypi.package_releases(req["pip_req"].name, True)
+                available = pypi.package_releases(req["pip_req"].name, True) or pypi.package_releases(req["pip_req"].name.replace('-', '_'), True)
                 available_version = self._available_version(dist_version, available)
 
                 if not available_version:
@@ -182,12 +186,18 @@ class Command(BaseCommand):
 
         Freeze at the commit hash (sha)::
             git+git://github.com/django/django.git@393c268e725f5b229ecb554f3fac02cfc250d2df#egg=Django
+            https://github.com/django/django/archive/393c268e725f5b229ecb554f3fac02cfc250d2df.tar.gz#egg=Django
+            https://github.com/django/django/archive/393c268e725f5b229ecb554f3fac02cfc250d2df.zip#egg=Django
 
         Freeze with a branch name::
             git+git://github.com/django/django.git@master#egg=Django
+            https://github.com/django/django/archive/master.tar.gz#egg=Django
+            https://github.com/django/django/archive/master.zip#egg=Django
 
         Freeze with a tag::
             git+git://github.com/django/django.git@1.5b2#egg=Django
+            https://github.com/django/django/archive/1.5b2.tar.gz#egg=Django
+            https://github.com/django/django/archive/1.5b2.zip#egg=Django
 
         Do not freeze::
             git+git://github.com/django/django.git#egg=Django
@@ -200,7 +210,7 @@ class Command(BaseCommand):
             req_url = str(req_url)
             if req_url.startswith("git") and "github.com/" not in req_url:
                 continue
-            if req_url.endswith(".tar.gz") or req_url.endswith(".tar.bz2") or req_url.endswith(".zip"):
+            if req_url.endswith((".tar.gz", ".tar.bz2", ".zip")):
                 continue
 
             headers = {
@@ -209,7 +219,21 @@ class Command(BaseCommand):
             if self.github_api_token:
                 headers["Authorization"] = "token {0}".format(self.github_api_token)
             try:
-                user, repo = urlparse(req_url).path.split("#")[0].strip("/").rstrip("/").split("/")
+                path_parts = urlparse(req_url).path.split("#", 1)[0].strip("/").rstrip("/").split("/")
+
+                if len(path_parts) == 2:
+                    user, repo = path_parts
+
+                elif 'archive' in path_parts:
+                    # Supports URL of format:
+                    # https://github.com/django/django/archive/master.tar.gz#egg=Django
+                    # https://github.com/django/django/archive/master.zip#egg=Django
+                    user, repo = path_parts[:2]
+                    repo += '@' + path_parts[-1].replace('.tar.gz', '').replace('.zip', '')
+
+                else:
+                    self.style.ERROR("\nFailed to parse %r\n" % (req_url, ))
+                    continue
             except (ValueError, IndexError) as e:
                 print(self.style.ERROR("\nFailed to parse %r: %s\n" % (req_url, e)))
                 continue
@@ -249,7 +273,7 @@ class Command(BaseCommand):
 
                 if "message" in frozen_commit_data and frozen_commit_data["message"] == "Not Found":
                     msg = self.style.ERROR("{0} not found in {1}. Repo may be private.".format(frozen_commit_sha[:10], name))
-                elif frozen_commit_sha in [branch["commit"]["sha"] for branch in branch_data]:
+                elif frozen_commit_data["sha"] in [branch["commit"]["sha"] for branch in branch_data]:
                     msg = self.style.BOLD("up to date")
                 else:
                     msg = self.style.INFO("{0} is not the head of any branch".format(frozen_commit_data["sha"][:10]))
